@@ -33,7 +33,6 @@ import logging
 import os.path as op
 import numpy   as np
 
-import fsl.utils.path        as fslpath
 import fsl.data.image        as fslimage
 import fsl.data.featanalysis as featanalysis
 
@@ -48,46 +47,51 @@ def isMelodicImage(path):
 
 
     try:
-        path = fslimage.addExt(path, mustExist=True)
-    except:
+        path = fslimage.addExt(path)
+    except fslimage.PathError:
         return False
 
     dirname  = op.dirname( path)
     filename = op.basename(path)
+    filename = fslimage.removeExt(filename)
 
-    return filename.startswith('melodic_IC') and isMelodicDir(dirname)
+    prefixes = ['melodic_IC',
+                'melodic_oIC']
+
+    return any([filename == p for p in prefixes]) and isMelodicDir(dirname)
 
 
 def isMelodicDir(path):
-    """Returns ``True`` if the given path looks like it is contained within
-    a MELODIC directory, ``False`` otherwise. A melodic directory:
+    """Returns ``True`` if the given path looks like it is a MELODIC directory,
+    ``False`` otherwise. A MELODIC directory:
 
-      - Must be named ``*.ica``.
-      - Must contain a file called ``melodic_IC.nii.gz``.
+      - Must contain a file called ``melodic_IC.nii.gz`` or
+        ``melodic_oIC.nii.gz``.
       - Must contain a file called ``melodic_mix``.
       - Must contain a file called ``melodic_FTmix``.
     """
 
     path = op.abspath(path)
 
-    if op.isdir(path): dirname = path
-    else:              dirname = op.dirname(path)
-
-    sufs = ['.ica']
-
-    if not any([dirname.endswith(suf) for suf in sufs]):
+    if not op.isdir(path):
         return False
 
-    # Must contain an image file called melodic_IC
-    try:
-        fslimage.addExt(op.join(dirname, 'melodic_IC'), mustExist=True)
-    except fslimage.PathError:
+    # Must contain an image file called
+    # melodic_IC or melodic_oIC
+    prefixes = ['melodic_IC', 'melodic_oIC']
+    for p in prefixes:
+        try:
+            fslimage.addExt(op.join(path, p))
+            break
+        except fslimage.PathError:
+            pass
+    else:
         return False
 
     # Must contain files called
     # melodic_mix and melodic_FTmix
-    if not op.exists(op.join(dirname, 'melodic_mix')):   return False
-    if not op.exists(op.join(dirname, 'melodic_FTmix')): return False
+    if not op.exists(op.join(path, 'melodic_mix')):   return False
+    if not op.exists(op.join(path, 'melodic_FTmix')): return False
 
     return True
 
@@ -97,10 +101,13 @@ def getAnalysisDir(path):
     to that MELODIC directory is returned. Otherwise, ``None`` is returned.
     """
 
-    meldir = fslpath.deepest(path, ['.ica'])
+    if not op.isdir(path):
+        path = op.dirname(path)
 
-    if meldir is not None and isMelodicDir(meldir):
-        return meldir
+    while path not in (op.sep, ''):
+        if isMelodicDir(path):
+            return path
+        path = op.dirname(path)
 
     return None
 
@@ -128,7 +135,7 @@ def getDataFile(meldir):
 
     dataFile = op.join(topDir, 'filtered_func_data')
 
-    try:                       return fslimage.addExt(dataFile, mustExist=True)
+    try:                       return fslimage.addExt(dataFile)
     except fslimage.PathError: return None
 
 
@@ -139,7 +146,10 @@ def getMeanFile(meldir):
 
 def getICFile(meldir):
     """Returns the path to the melodic IC image. """
-    return fslimage.addExt(op.join(meldir, 'melodic_IC'))
+    try:
+        return fslimage.addExt(op.join(meldir, 'melodic_IC'))
+    except fslimage.PathError:
+        return fslimage.addExt(op.join(meldir, 'melodic_oIC'))
 
 
 def getMixFile(meldir):
